{% if widget.wrap_label %}
  <label {% if widget.attrs.id %}for="{{ widget.attrs.id }}"{% endif %}
         class="flex gap-2 items-center my-1">
  {% endif %}
  <input type="{{ widget.type }}"
         name="{{ widget.name }}"
         {% if widget.value != None %} class="checkbox checkbox-sm checkbox-primary border" value="{{ widget.value|stringformat:'s' }}"{% endif %}
         {% include "django/forms/widgets/attrs.html" %}>
  {% if widget.wrap_label %}
    {{ widget.label }}
  </label>
{% endif %}
