{% extends "htmx/_base_form_modal.html" %}
{% block form_control %}
  hx-post="{% url endpoint|default:'htmx:incidents-update' action=action %}"
  {% if action_type == "bulk-update" %}
    hx-include="[name='incident_ids']"
  {% else %}
    hx-vals='{"incident_ids": [{{ incident.pk }}] }'
  {% endif %}
{% endblock form_control %}
