# Generated by Django 4.2.16 on 2024-11-07 11:02

from django.db import migrations


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("argus_auth", "0004_add_preferences_model"),
    ]

    operations = [
        migrations.CreateModel(
            name="ArgusHtmxPreferences",
            fields=[],
            options={
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("argus_auth.preferences",),
        ),
    ]
